import java.text.MessageFormat;
import java.util.HashMap;
import java.util.List;

import co.ecg.alpaca.toolkit.model.BroadWorksServer;
import co.ecg.alpaca.toolkit.generated.User;
import co.ecg.alpaca.toolkit.generated.User.UserGetRegistrationListRequest;
import co.ecg.alpaca.toolkit.generated.User.UserGetRegistrationListResponse;
import co.ecg.alpaca.toolkit.generated.tables.UserRegistrationTableRow;
import co.ecg.alpaca.toolkit.helper.user.UserHelper;
import co.ecg.utilities.properties.P;

/**
 * Retrieve the registration list for all Users in the BroadWorks system and
 * display the information
 *
 * @author Matthew Keathley - mkeathley@e-c-group.com
 */
public class ResponsePerUserExample {

    public static void main(String[] args) {
        try {
            // Retrieves the Server, Username, and Password from the
            // alpaca.properties.xml file
            String server = P.CoreProperties.getPrimaryBroadWorksServerAddress();
            String username = P.CoreProperties.getPrimaryBroadWorksUserId();
            String password = P.CoreProperties.getPrimaryBroadWorksPassword();

            // Open the connection to BroadWorks
            BroadWorksServer bws = BroadWorksServer.getBroadWorksServer(server, username, password, null);

            // Retrieve User List
            List<User> users = UserHelper.getAllUsersInSystem(bws);

            // Query BroadWorks for the UserGetRegistrationListResponse for each
            // user in the users list.
            HashMap<User, UserGetRegistrationListResponse> userRegistrationMap =
                UserHelper.getResponsePerUserMap(bws, users, UserGetRegistrationListRequest.class);

            // Iterate through the Users
            for (User u : users) {
                UserGetRegistrationListResponse registrationResponse = userRegistrationMap.get(u);

                // Sanity check and verify that the response is valid
                if (registrationResponse != null && !registrationResponse.isErrorResponse()) {
                    for (UserRegistrationTableRow row : registrationResponse.getRegistrationTable()) {
                        System.out.println(MessageFormat.format("{0}\t{1}\t{2}\t{3}\t{4}",
                            u.getUserId(),
                            row.getEndpointType(),
                            row.getDeviceName(),
                            row.getURI(),
                            row.getExpiration()));
                    }
                } else {
                    // User does not have active registrations
                }
            }

            System.exit(0);
        } catch (Exception ex) {
            System.out.println("Error while retrieving User Registrations - " + ex.getMessage());
            System.exit(1);
        }
    }
}